@@ -5,7 +5,7 @@ class Logical(Argument):
     c_types = {"4":"ctypes.c_bool"}
     default_singleton = "0"
 
-    # Add a warning that 
+    # Add a warning about logical arrays.
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         if (self.dimension is not None):
@@ -16,5 +16,5 @@ class Logical(Argument):
             from fmodpy.config import show_warnings
             if show_warnings:
                 import warnings
-                warnings.warn("Fortran LOGICAL arrays must be given as 32-big integers.")
+                warnings.warn("Fortran LOGICAL arrays must be given as 32-bit integers.")
 
